# MCA Projen JSii Example

[![License](https://img.shields.io/badge/License-Apache%202.0-yellowgreen.svg)](https://opensource.org/licenses/Apache-2.0)
[![Gitpod ready-to-code](https://img.shields.io/badge/Gitpod-ready--to--code-blue?logo=gitpod)](https://gitpod.io/#https://github.com/marciocadev/mca-projen-jsii-example)
[![NPM version](https://img.shields.io/npm/v/mca-projen-jsii-example?label=pypi%20package&color=brightgreen)](https://badge.fury.io/js/mca-projen-jsii-example)
[![PyPI version](https://img.shields.io/pypi/v/mca-projen-jsii-example?label=pypi%20package&color=brightgreen)](https://badge.fury.io/py/mca-projen-jsii-example)
[![NuGet version](https://img.shields.io/nuget/v/Projen.Jsii?label=nuget%20package&color=brightgreen)](https://badge.fury.io/nu/Projen.Jsii)
[![Maven Central](https://img.shields.io/maven-central/v/com.marciocadev/mca-projen-jsii-example.svg?label=maven%20central&color=brightgreen)](https://search.maven.org/search?q=g:%22com.marciocadev%22%20AND%20a:%22mca-projen-jsii-example%22)
[![Go Reference](https://pkg.go.dev/badge/github.com/marciocadev/mca-projen-jsii-example-go/mcaprojenjsiiexample.svg)](https://pkg.go.dev/github.com/marciocadev/mca-projen-jsii-example-go/mcaprojenjsiiexample)
[![release](https://github.com/marciocadev/mca-projen-jsii-example/actions/workflows/release.yml/badge.svg)](https://github.com/marciocadev/mca-projen-jsii-example/actions/workflows/release.yml)

<!-- Test  --><!-- [![Maven](https://img.shields.io/maven-central/v/com.marciocadev/mca-projen-jsii-example?label=version&color=brightgreen&logo=java)](https://search.maven.org/search?q=g:%22com.marciocadev%22%20AND%20a:%22mca-projen-jsii-example%22)
[![Go Version](https://img.shields.io/badge/dynamic/json?color=brightgreen&query=%24.Version&url=https%3A%2F%2Fproxy.golang.org%2Fgithub.com%2Fmarciocadev%2Fmca-projen-jsii-example%2F%40v%2Fv1.1.7.info&logo=go&label=version)](https://pkg.go.dev/github.com/marciocadev/mca-projen-jsii-example-go)
[![GitHub Workflow Status](https://img.shields.io/github/workflow/status/marciocadev/mca-projen-jsii-example/release?logo=github&label=release)](https://github.com/marciocadev/mca-projen-jsii-example/actions/workflows/release.yml) --><!--
[![Maven Central](https://maven-badges.herokuapp.com/maven-central/com.marciocadev/mca-projen-jsii-example/badge.svg)](https://maven-badges.herokuapp.com/maven-central/com.marciocadev/mca-projen-jsii-example)

[![Go Reference](https://pkg.go.dev/badge/github.com/projen/projen-go.svg)](https://pkg.go.dev/github.com/projen/projen-go/projen) --><!-- [![npm version](https://badge.fury.io/js/mca-projen-jsii-example.svg)](https://badge.fury.io/js/mca-projen-jsii-example) --><!-- [![PyPI version](https://badge.fury.io/py/mca-projen-jsii-example.svg)](https://badge.fury.io/py/mca-projen-jsii-example) --><!-- [![NuGet version](https://badge.fury.io/nu/Projen.Jsii.svg)](https://badge.fury.io/nu/Projen.Jsii) -->

The **MCA Projen JSii Example** it's a test project to learn how deploy at NPM, PyPi and Maven repositories, auto-versioning and runing git actions on commits
